Function ok
fn ok<T, E>(t: T) -> Ready<Result<T, E>>
Create a future that is immediately ready with a success value.
Examples
# block_on;
okfn ok<T, E>(t: T) -> Ready<Result<T, E>>
Create a future that is immediately ready with a success value.
# block_on;