Function ready
fn ready<T>(t: T) -> Ready<T>
Creates a future that is immediately ready with a value.
Examples
# block_on;
readyfn ready<T>(t: T) -> Ready<T>
Creates a future that is immediately ready with a value.
# block_on;