Struct Remote

struct Remote<Fut: Future> { ... }

A future which sends its output to the corresponding RemoteHandle. Created by remote_handle.

Implementations

impl<'__pin, Fut: Future> Unpin for Remote<Fut>

impl<F> IntoFuture for Remote<Fut>

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<Fut> Freeze for Remote<Fut>

impl<Fut> RefUnwindSafe for Remote<Fut>

impl<Fut> Send for Remote<Fut>

impl<Fut> Sync for Remote<Fut>

impl<Fut> UnsafeUnpin for Remote<Fut>

impl<Fut> UnwindSafe for Remote<Fut>

impl<Fut: Future + fmt::Debug> Debug for Remote<Fut>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<Fut: Future> Future for Remote<Fut>

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<()>

impl<T> Any for Remote<Fut>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Remote<Fut>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Remote<Fut>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Remote<Fut>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> FutureExt for Remote<Fut>

impl<T, U> Into for Remote<Fut>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Remote<Fut>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Remote<Fut>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>