Struct futures_util::future::Shared [−][src]
#[must_use = "futures do nothing unless you `.await` or poll them"]pub struct Shared<Fut: Future> { /* fields omitted */ }
Future for the shared method.
Implementations
impl<Fut> Shared<Fut> where
Fut: Future,
Fut::Output: Clone, [src]
impl<Fut> Shared<Fut> where
Fut: Future,
Fut::Output: Clone, [src]pub fn peek(&self) -> Option<&Fut::Output>[src]
Returns Some containing a reference to this Shared’s output if
it has already been computed by a clone or None if it hasn’t been
computed yet or this Shared already returned its output from
poll.
pub fn downgrade(&self) -> Option<WeakShared<Fut>>[src]
Creates a new WeakShared for this Shared.
Returns None if it has already been polled to completion.