Struct Buffer

struct Buffer<Si, Item> { ... }

Sink for the buffer method.

Implementations

impl<Si: Sink<Item>, Item> Buffer<Si, Item>

fn get_ref(self: &Self) -> &Si

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut Si

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Si>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> Si

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, Si, Item> Unpin for Buffer<Si, Item>

impl<S> TryStreamExt for Buffer<Si, Item>

impl<S, Item> FusedStream for Buffer<S, Item>

fn is_terminated(self: &Self) -> bool

impl<S, Item> Stream for Buffer<S, Item>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<S as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<S, T, E> TryStream for Buffer<Si, Item>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<Si, Item> Freeze for Buffer<Si, Item>

impl<Si, Item> RefUnwindSafe for Buffer<Si, Item>

impl<Si, Item> Send for Buffer<Si, Item>

impl<Si, Item> Sync for Buffer<Si, Item>

impl<Si, Item> UnsafeUnpin for Buffer<Si, Item>

impl<Si, Item> UnwindSafe for Buffer<Si, Item>

impl<Si: $crate::fmt::Debug, Item: $crate::fmt::Debug> Debug for Buffer<Si, Item>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<Si: Sink<Item>, Item> Sink for Buffer<Si, Item>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>

impl<T> Any for Buffer<Si, Item>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Buffer<Si, Item>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Buffer<Si, Item>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Buffer<Si, Item>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for Buffer<Si, Item>

impl<T, Item> SinkExt for Buffer<Si, Item>

impl<T, U> Into for Buffer<Si, Item>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Buffer<Si, Item>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Buffer<Si, Item>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>