Struct With

struct With<Si, Item, U, Fut, F> { ... }

Sink for the with method.

Implementations

impl<Si, Item, U, Fut, F, E> With<Si, Item, U, Fut, F>

fn get_ref(self: &Self) -> &Si

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut Si

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Si>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> Si

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, Si, Item, U, Fut, F> Unpin for With<Si, Item, U, Fut, F>

impl<S> TryStreamExt for With<Si, Item, U, Fut, F>

impl<S, Item, U, Fut, F> Stream for With<S, Item, U, Fut, F>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<S, T, E> TryStream for With<Si, Item, U, Fut, F>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<Si, Item, U, Fut, F> Clone for With<Si, Item, U, Fut, F>

fn clone(self: &Self) -> Self

impl<Si, Item, U, Fut, F> Debug for With<Si, Item, U, Fut, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<Si, Item, U, Fut, F> Freeze for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F> RefUnwindSafe for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F> Send for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F> Sync for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F> UnsafeUnpin for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F> UnwindSafe for With<Si, Item, U, Fut, F>

impl<Si, Item, U, Fut, F, E> Sink for With<Si, Item, U, Fut, F>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: U) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>

impl<T> Any for With<Si, Item, U, Fut, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for With<Si, Item, U, Fut, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for With<Si, Item, U, Fut, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for With<Si, Item, U, Fut, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for With<Si, Item, U, Fut, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for With<Si, Item, U, Fut, F>

impl<T> ToOwned for With<Si, Item, U, Fut, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, Item> SinkExt for With<Si, Item, U, Fut, F>

impl<T, U> Into for With<Si, Item, U, Fut, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for With<Si, Item, U, Fut, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for With<Si, Item, U, Fut, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>