Struct IterMut

struct IterMut<'a, Fut: Unpin>(_)

Mutable iterator over all futures in the unordered set.

Implementations

impl<'a, Fut> Freeze for IterMut<'a, Fut>

impl<'a, Fut> RefUnwindSafe for IterMut<'a, Fut>

impl<'a, Fut> Send for IterMut<'a, Fut>

impl<'a, Fut> Sync for IterMut<'a, Fut>

impl<'a, Fut> Unpin for IterMut<'a, Fut>

impl<'a, Fut> UnsafeUnpin for IterMut<'a, Fut>

impl<'a, Fut> UnwindSafe for IterMut<'a, Fut>

impl<'a, Fut: $crate::fmt::Debug + Unpin> Debug for IterMut<'a, Fut>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, Fut: Unpin> Iterator for IterMut<'a, Fut>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<Fut: Unpin> ExactSizeIterator for IterMut<'_, Fut>

impl<I> IntoIterator for IterMut<'a, Fut>

fn into_iter(self: Self) -> I

impl<T> Any for IterMut<'a, Fut>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for IterMut<'a, Fut>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for IterMut<'a, Fut>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for IterMut<'a, Fut>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for IterMut<'a, Fut>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for IterMut<'a, Fut>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for IterMut<'a, Fut>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>