Struct IterPinRef

struct IterPinRef<'a, Fut> { ... }

Immutable iterator over all futures in the unordered set.

Implementations

impl<'a, Fut> Freeze for IterPinRef<'a, Fut>

impl<'a, Fut> Iterator for IterPinRef<'a, Fut>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<'a, Fut> RefUnwindSafe for IterPinRef<'a, Fut>

impl<'a, Fut> Unpin for IterPinRef<'a, Fut>

impl<'a, Fut> UnsafeUnpin for IterPinRef<'a, Fut>

impl<'a, Fut> UnwindSafe for IterPinRef<'a, Fut>

impl<'a, Fut: $crate::fmt::Debug> Debug for IterPinRef<'a, Fut>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<Fut> ExactSizeIterator for IterPinRef<'_, Fut>

impl<Fut: Send> Send for IterPinRef<'_, Fut>

impl<Fut: Sync> Sync for IterPinRef<'_, Fut>

impl<I> IntoIterator for IterPinRef<'a, Fut>

fn into_iter(self: Self) -> I

impl<T> Any for IterPinRef<'a, Fut>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for IterPinRef<'a, Fut>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for IterPinRef<'a, Fut>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for IterPinRef<'a, Fut>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for IterPinRef<'a, Fut>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for IterPinRef<'a, Fut>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for IterPinRef<'a, Fut>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>