Struct Iter

struct Iter<'a, St: Unpin>(_)

Immutable iterator over all streams in the unordered set.

Implementations

impl<'a, St> Freeze for Iter<'a, St>

impl<'a, St> RefUnwindSafe for Iter<'a, St>

impl<'a, St> Send for Iter<'a, St>

impl<'a, St> Sync for Iter<'a, St>

impl<'a, St> Unpin for Iter<'a, St>

impl<'a, St> UnsafeUnpin for Iter<'a, St>

impl<'a, St> UnwindSafe for Iter<'a, St>

impl<'a, St: $crate::fmt::Debug + Unpin> Debug for Iter<'a, St>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, St: Stream + Unpin> Iterator for Iter<'a, St>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<I> IntoIterator for Iter<'a, St>

fn into_iter(self: Self) -> I

impl<St: Stream + Unpin> ExactSizeIterator for Iter<'_, St>

impl<T> Any for Iter<'a, St>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Iter<'a, St>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Iter<'a, St>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Iter<'a, St>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Iter<'a, St>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Iter<'a, St>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Iter<'a, St>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>