Struct AbortRegistration

struct AbortRegistration { ... }

A registration handle for an Abortable task. Values of this type can be acquired from AbortHandle::new and are used in calls to Abortable::new.

Implementations

impl AbortRegistration

fn handle(self: &Self) -> AbortHandle

Create an AbortHandle from the given AbortRegistration.

The created AbortHandle is functionally the same as any other AbortHandles that are associated with the same AbortRegistration, such as the one created by AbortHandle::new_pair.

impl Debug for AbortRegistration

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for AbortRegistration

impl RefUnwindSafe for AbortRegistration

impl Send for AbortRegistration

impl Sync for AbortRegistration

impl Unpin for AbortRegistration

impl UnsafeUnpin for AbortRegistration

impl UnwindSafe for AbortRegistration

impl<T> Any for AbortRegistration

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AbortRegistration

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AbortRegistration

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for AbortRegistration

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for AbortRegistration

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AbortRegistration

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AbortRegistration

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>