Struct AndThen
struct AndThen<St, Fut, F> { ... }
Stream for the and_then method.
Implementations
impl<St, Fut, F> AndThen<St, Fut, F>
fn get_ref(self: &Self) -> &StAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut StAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> StConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St, Fut, F> Unpin for AndThen<St, Fut, F>
impl<S> TryStreamExt for AndThen<St, Fut, F>
impl<S, Fut, F, Item> Sink for AndThen<S, Fut, F>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
impl<S, T, E> TryStream for AndThen<St, Fut, F>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<St, Fut, F> Debug for AndThen<St, Fut, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St, Fut, F> Freeze for AndThen<St, Fut, F>
impl<St, Fut, F> FusedStream for AndThen<St, Fut, F>
fn is_terminated(self: &Self) -> bool
impl<St, Fut, F> RefUnwindSafe for AndThen<St, Fut, F>
impl<St, Fut, F> Send for AndThen<St, Fut, F>
impl<St, Fut, F> Stream for AndThen<St, Fut, F>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<St, Fut, F> Sync for AndThen<St, Fut, F>
impl<St, Fut, F> UnsafeUnpin for AndThen<St, Fut, F>
impl<St, Fut, F> UnwindSafe for AndThen<St, Fut, F>
impl<T> Any for AndThen<St, Fut, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for AndThen<St, Fut, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for AndThen<St, Fut, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for AndThen<St, Fut, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for AndThen<St, Fut, F>
impl<T, Item> SinkExt for AndThen<St, Fut, F>
impl<T, U> Into for AndThen<St, Fut, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for AndThen<St, Fut, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for AndThen<St, Fut, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>