Struct BufferUnordered

struct BufferUnordered<St> { ... }
where
    St: Stream

Stream for the buffer_unordered method.

Implementations

impl<St> BufferUnordered<St>

fn get_ref(self: &Self) -> &St

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut St

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> St

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, St> Unpin for BufferUnordered<St>

impl<S> TryStreamExt for BufferUnordered<St>

impl<S, Item> Sink for BufferUnordered<S>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>

impl<S, T, E> TryStream for BufferUnordered<St>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<St> Debug for BufferUnordered<St>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<St> Freeze for BufferUnordered<St>

impl<St> FusedStream for BufferUnordered<St>

fn is_terminated(self: &Self) -> bool

impl<St> RefUnwindSafe for BufferUnordered<St>

impl<St> Send for BufferUnordered<St>

impl<St> Stream for BufferUnordered<St>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<St> Sync for BufferUnordered<St>

impl<St> UnsafeUnpin for BufferUnordered<St>

impl<St> UnwindSafe for BufferUnordered<St>

impl<T> Any for BufferUnordered<St>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for BufferUnordered<St>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for BufferUnordered<St>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for BufferUnordered<St>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for BufferUnordered<St>

impl<T, Item> SinkExt for BufferUnordered<St>

impl<T, U> Into for BufferUnordered<St>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for BufferUnordered<St>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for BufferUnordered<St>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>