Struct Iter

struct Iter<I> { ... }

Stream for the iter function.

Implementations

impl<I> Iter<I>

fn get_ref(self: &Self) -> &I

Acquires a reference to the underlying iterator that this stream is pulling from.

fn get_mut(self: &mut Self) -> &mut I

Acquires a mutable reference to the underlying iterator that this stream is pulling from.

fn into_inner(self: Self) -> I

Consumes this stream, returning the underlying iterator.

impl<I> Freeze for Iter<I>

impl<I> RefUnwindSafe for Iter<I>

impl<I> Send for Iter<I>

impl<I> Stream for Iter<I>

fn poll_next(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Option<<I as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<I> Sync for Iter<I>

impl<I> Unpin for Iter<I>

impl<I> UnsafeUnpin for Iter<I>

impl<I> UnwindSafe for Iter<I>

impl<I: $crate::clone::Clone> Clone for Iter<I>

fn clone(self: &Self) -> Iter<I>

impl<I: $crate::fmt::Debug> Debug for Iter<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S> TryStreamExt for Iter<I>

impl<S, T, E> TryStream for Iter<I>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<T> Any for Iter<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Iter<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Iter<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Iter<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Iter<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for Iter<I>

impl<T> ToOwned for Iter<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Iter<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Iter<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Iter<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>