Struct Map

struct Map<St, F> { ... }

Stream for the map method.

Implementations

impl<St, F> Map<St, F>

fn get_ref(self: &Self) -> &St

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut St

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> St

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, St, F> Unpin for Map<St, F>

impl<S> TryStreamExt for Map<St, F>

impl<S, T, E> TryStream for Map<St, F>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<St, F> Debug for Map<St, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<St, F> Freeze for Map<St, F>

impl<St, F> FusedStream for Map<St, F>

fn is_terminated(self: &Self) -> bool

impl<St, F> RefUnwindSafe for Map<St, F>

impl<St, F> Send for Map<St, F>

impl<St, F> Stream for Map<St, F>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<St, F> Sync for Map<St, F>

impl<St, F> UnsafeUnpin for Map<St, F>

impl<St, F> UnwindSafe for Map<St, F>

impl<St, F, Item> Sink for Map<St, F>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>

impl<T> Any for Map<St, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Map<St, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Map<St, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Map<St, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for Map<St, F>

impl<T, Item> SinkExt for Map<St, F>

impl<T, U> Into for Map<St, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Map<St, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Map<St, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>