Struct MapErr

struct MapErr<St, F> { ... }

Stream for the map_err method.

Implementations

impl<St, F> MapErr<St, F>

fn get_ref(self: &Self) -> &St

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut St

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> St

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, St, F> Unpin for MapErr<St, F>

impl<S> TryStreamExt for MapErr<St, F>

impl<S, T, E> TryStream for MapErr<St, F>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<St, F> Debug for MapErr<St, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<St, F> Freeze for MapErr<St, F>

impl<St, F> FusedStream for MapErr<St, F>

fn is_terminated(self: &Self) -> bool

impl<St, F> RefUnwindSafe for MapErr<St, F>

impl<St, F> Send for MapErr<St, F>

impl<St, F> Stream for MapErr<St, F>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<St, F> Sync for MapErr<St, F>

impl<St, F> UnsafeUnpin for MapErr<St, F>

impl<St, F> UnwindSafe for MapErr<St, F>

impl<T> Any for MapErr<St, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MapErr<St, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MapErr<St, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for MapErr<St, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for MapErr<St, F>

impl<T, Item> SinkExt for MapErr<St, F>

impl<T, U> Into for MapErr<St, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MapErr<St, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MapErr<St, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<_Item, St, F> Sink for MapErr<St, F>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: _Item) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>