Struct ReadyChunks
struct ReadyChunks<St: Stream> { ... }
Stream for the ready_chunks method.
Implementations
impl<St: Stream> ReadyChunks<St>
fn get_ref(self: &Self) -> &StAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut StAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> StConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St: Stream> Unpin for ReadyChunks<St>
impl<S, Item> Sink for ReadyChunks<S>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
impl<St> Freeze for ReadyChunks<St>
impl<St> RefUnwindSafe for ReadyChunks<St>
impl<St> Send for ReadyChunks<St>
impl<St> Sync for ReadyChunks<St>
impl<St> UnsafeUnpin for ReadyChunks<St>
impl<St> UnwindSafe for ReadyChunks<St>
impl<St: $crate::fmt::Debug + Stream> Debug for ReadyChunks<St>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St: Stream> FusedStream for ReadyChunks<St>
fn is_terminated(self: &Self) -> bool
impl<St: Stream> Stream for ReadyChunks<St>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<T> Any for ReadyChunks<St>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ReadyChunks<St>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ReadyChunks<St>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ReadyChunks<St>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for ReadyChunks<St>
impl<T, Item> SinkExt for ReadyChunks<St>
impl<T, U> Into for ReadyChunks<St>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ReadyChunks<St>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ReadyChunks<St>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>