Struct RepeatWith

struct RepeatWith<F> { ... }

An stream that repeats elements of type A endlessly by applying the provided closure F: FnMut() -> A.

This struct is created by the [repeat_with()] function. See its documentation for more.

Implementations

impl<A, F: FnMut() -> A> FusedStream for RepeatWith<F>

fn is_terminated(self: &Self) -> bool

impl<A, F: FnMut() -> A> Stream for RepeatWith<F>

fn poll_next(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, F: FnMut() -> A> Unpin for RepeatWith<F>

impl<F> Freeze for RepeatWith<F>

impl<F> RefUnwindSafe for RepeatWith<F>

impl<F> Send for RepeatWith<F>

impl<F> Sync for RepeatWith<F>

impl<F> UnsafeUnpin for RepeatWith<F>

impl<F> UnwindSafe for RepeatWith<F>

impl<F: $crate::clone::Clone> Clone for RepeatWith<F>

fn clone(self: &Self) -> RepeatWith<F>

impl<F: $crate::fmt::Debug> Debug for RepeatWith<F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S> TryStreamExt for RepeatWith<F>

impl<S, T, E> TryStream for RepeatWith<F>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<T> Any for RepeatWith<F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RepeatWith<F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RepeatWith<F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for RepeatWith<F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for RepeatWith<F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for RepeatWith<F>

impl<T> ToOwned for RepeatWith<F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for RepeatWith<F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RepeatWith<F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RepeatWith<F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>