Struct SelectWithStrategy
struct SelectWithStrategy<St1, St2, Clos, State> { ... }
Stream for the [select_with_strategy()] function. See function docs for details.
Implementations
impl<St1, St2, Clos, State> SelectWithStrategy<St1, St2, Clos, State>
fn get_ref(self: &Self) -> (&St1, &St2)Acquires a reference to the underlying streams that this combinator is pulling from.
fn get_mut(self: &mut Self) -> (&mut St1, &mut St2)Acquires a mutable reference to the underlying streams that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> (Pin<&mut St1>, Pin<&mut St2>)Acquires a pinned mutable reference to the underlying streams that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> (St1, St2)Consumes this combinator, returning the underlying streams.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St1, St2, Clos, State> Unpin for SelectWithStrategy<St1, St2, Clos, State>
impl<S> TryStreamExt for SelectWithStrategy<St1, St2, Clos, State>
impl<S, T, E> TryStream for SelectWithStrategy<St1, St2, Clos, State>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<St1, St2, Clos, State> Debug for SelectWithStrategy<St1, St2, Clos, State>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St1, St2, Clos, State> Freeze for SelectWithStrategy<St1, St2, Clos, State>
impl<St1, St2, Clos, State> FusedStream for SelectWithStrategy<St1, St2, Clos, State>
fn is_terminated(self: &Self) -> bool
impl<St1, St2, Clos, State> RefUnwindSafe for SelectWithStrategy<St1, St2, Clos, State>
impl<St1, St2, Clos, State> Send for SelectWithStrategy<St1, St2, Clos, State>
impl<St1, St2, Clos, State> Stream for SelectWithStrategy<St1, St2, Clos, State>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<St1 as >::Item>>
impl<St1, St2, Clos, State> Sync for SelectWithStrategy<St1, St2, Clos, State>
impl<St1, St2, Clos, State> UnsafeUnpin for SelectWithStrategy<St1, St2, Clos, State>
impl<St1, St2, Clos, State> UnwindSafe for SelectWithStrategy<St1, St2, Clos, State>
impl<T> Any for SelectWithStrategy<St1, St2, Clos, State>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SelectWithStrategy<St1, St2, Clos, State>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SelectWithStrategy<St1, St2, Clos, State>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for SelectWithStrategy<St1, St2, Clos, State>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for SelectWithStrategy<St1, St2, Clos, State>
impl<T, U> Into for SelectWithStrategy<St1, St2, Clos, State>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SelectWithStrategy<St1, St2, Clos, State>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SelectWithStrategy<St1, St2, Clos, State>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>