Struct SplitSink
struct SplitSink<S, Item> { ... }
A Sink part of the split pair
Implementations
impl<S, Item> SplitSink<S, Item>
fn is_pair_of(self: &Self, other: &SplitStream<S>) -> boolReturns
trueif theSplitStream<S>andSplitSink<S>originate from the same call toStreamExt::split.
impl<S: Sink<Item> + Unpin, Item> SplitSink<S, Item>
fn reunite(self: Self, other: SplitStream<S>) -> Result<S, ReuniteError<S, Item>>Attempts to put the two "halves" of a split
Stream + Sinkback together. Succeeds only if theSplitStream<S>andSplitSink<S>are a matching pair originating from the same call toStreamExt::split.
impl<S, Item> Freeze for SplitSink<S, Item>
impl<S, Item> RefUnwindSafe for SplitSink<S, Item>
impl<S, Item> Send for SplitSink<S, Item>
impl<S, Item> Sync for SplitSink<S, Item>
impl<S, Item> Unpin for SplitSink<S, Item>
impl<S, Item> UnsafeUnpin for SplitSink<S, Item>
impl<S, Item> UnwindSafe for SplitSink<S, Item>
impl<S: $crate::fmt::Debug, Item: $crate::fmt::Debug> Debug for SplitSink<S, Item>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Sink<Item>, Item> Sink for SplitSink<S, Item>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <S as >::Error>>fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <S as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <S as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <S as >::Error>>
impl<T> Any for SplitSink<S, Item>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SplitSink<S, Item>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SplitSink<S, Item>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for SplitSink<S, Item>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, Item> SinkExt for SplitSink<S, Item>
impl<T, U> Into for SplitSink<S, Item>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SplitSink<S, Item>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SplitSink<S, Item>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>