Struct SplitStream

struct SplitStream<S>(_)

A Stream part of the split pair

Implementations

impl<S> SplitStream<S>

fn is_pair_of<Item>(self: &Self, other: &SplitSink<S, Item>) -> bool

Returns true if the SplitStream<S> and SplitSink<S> originate from the same call to StreamExt::split.

impl<S: Unpin> SplitStream<S>

fn reunite<Item>(self: Self, other: SplitSink<S, Item>) -> Result<S, ReuniteError<S, Item>>
where
    S: Sink<Item>

Attempts to put the two "halves" of a split Stream + Sink back together. Succeeds only if the SplitStream<S> and SplitSink<S> are a matching pair originating from the same call to StreamExt::split.

impl<S> Freeze for SplitStream<S>

impl<S> RefUnwindSafe for SplitStream<S>

impl<S> Send for SplitStream<S>

impl<S> Sync for SplitStream<S>

impl<S> TryStreamExt for SplitStream<S>

impl<S> Unpin for SplitStream<S>

impl<S> UnsafeUnpin for SplitStream<S>

impl<S> UnwindSafe for SplitStream<S>

impl<S, T, E> TryStream for SplitStream<S>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<S: $crate::fmt::Debug> Debug for SplitStream<S>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S: Stream> Stream for SplitStream<S>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<S as >::Item>>

impl<T> Any for SplitStream<S>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SplitStream<S>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SplitStream<S>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for SplitStream<S>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for SplitStream<S>

impl<T, U> Into for SplitStream<S>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SplitStream<S>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SplitStream<S>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>