Struct TryChunks
struct TryChunks<St: TryStream> { ... }
Stream for the try_chunks method.
Implementations
impl<St: TryStream> TryChunks<St>
fn get_ref(self: &Self) -> &StAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut StAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> StConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St: TryStream> Unpin for TryChunks<St>
impl<S> TryStreamExt for TryChunks<St>
impl<S, Item> Sink for TryChunks<S>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
impl<S, T, E> TryStream for TryChunks<St>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<St> Freeze for TryChunks<St>
impl<St> RefUnwindSafe for TryChunks<St>
impl<St> Send for TryChunks<St>
impl<St> Sync for TryChunks<St>
impl<St> UnsafeUnpin for TryChunks<St>
impl<St> UnwindSafe for TryChunks<St>
impl<St: $crate::fmt::Debug + TryStream> Debug for TryChunks<St>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St: TryStream + FusedStream> FusedStream for TryChunks<St>
fn is_terminated(self: &Self) -> bool
impl<St: TryStream> Stream for TryChunks<St>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<T> Any for TryChunks<St>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TryChunks<St>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TryChunks<St>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for TryChunks<St>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for TryChunks<St>
impl<T, Item> SinkExt for TryChunks<St>
impl<T, U> Into for TryChunks<St>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TryChunks<St>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TryChunks<St>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>