Trait AsyncSeekExt

trait AsyncSeekExt: AsyncSeek

An extension trait which adds utility methods to AsyncSeek types.

Provided Methods

fn seek(self: &mut Self, pos: SeekFrom) -> Seek<'_, Self>
where
    Self: Unpin

Creates a future which will seek an IO object, and then yield the new position in the object and the object itself.

In the case of an error the buffer and the object will be discarded, with the error yielded.

fn stream_position(self: &mut Self) -> Seek<'_, Self>
where
    Self: Unpin

Creates a future which will return the current seek position from the start of the stream.

This is equivalent to self.seek(SeekFrom::Current(0)).

Implementors