Trait TryStreamExt

trait TryStreamExt: TryStream

Adapters specific to Result-returning streams

Provided Methods

fn err_into<E>(self: Self) -> ErrInto<Self, E>
where
    Self: Sized,
    <Self as >::Error: Into<E>

Wraps the current stream in a new stream which converts the error type into the one provided.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};

let mut stream =
    stream::iter(vec![Ok(()), Err(5i32)])
        .err_into::<i64>();

assert_eq!(stream.try_next().await, Ok(Some(())));
assert_eq!(stream.try_next().await, Err(5i64));
# })
fn map_ok<T, F>(self: Self, f: F) -> MapOk<Self, F>
where
    Self: Sized,
    F: FnMut(<Self as >::Ok) -> T

Wraps the current stream in a new stream which maps the success value using the provided closure.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};

let mut stream =
    stream::iter(vec![Ok(5), Err(0)])
        .map_ok(|x| x + 2);

assert_eq!(stream.try_next().await, Ok(Some(7)));
assert_eq!(stream.try_next().await, Err(0));
# })
fn map_err<E, F>(self: Self, f: F) -> MapErr<Self, F>
where
    Self: Sized,
    F: FnMut(<Self as >::Error) -> E

Wraps the current stream in a new stream which maps the error value using the provided closure.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};

let mut stream =
    stream::iter(vec![Ok(5), Err(0)])
        .map_err(|x| x + 2);

assert_eq!(stream.try_next().await, Ok(Some(5)));
assert_eq!(stream.try_next().await, Err(2));
# })
fn and_then<Fut, F>(self: Self, f: F) -> AndThen<Self, Fut, F>
where
    F: FnMut(<Self as >::Ok) -> Fut,
    Fut: TryFuture<Error = <Self as >::Error>,
    Self: Sized

Chain on a computation for when a value is ready, passing the successful results to the provided closure f.

This function can be used to run a unit of work when the next successful value on a stream is ready. The closure provided will be yielded a value when ready, and the returned future will then be run to completion to produce the next value on this stream.

Any errors produced by this stream will not be passed to the closure, and will be passed through.

The returned value of the closure must implement the TryFuture trait and can represent some more work to be done before the composed stream is finished.

Note that this function consumes the receiving stream and returns a wrapped version of it.

To process the entire stream and return a single future representing success or error, use try_for_each instead.

Examples

use futures::channel::mpsc;
use futures::future;
use futures::stream::TryStreamExt;

let (_tx, rx) = mpsc::channel::<Result<i32, ()>>(1);

let rx = rx.and_then(|result| {
    future::ok(if result % 2 == 0 {
        Some(result)
    } else {
        None
    })
});
fn or_else<Fut, F>(self: Self, f: F) -> OrElse<Self, Fut, F>
where
    F: FnMut(<Self as >::Error) -> Fut,
    Fut: TryFuture<Ok = <Self as >::Ok>,
    Self: Sized

Chain on a computation for when an error happens, passing the erroneous result to the provided closure f.

This function can be used to run a unit of work and attempt to recover from an error if one happens. The closure provided will be yielded an error when one appears, and the returned future will then be run to completion to produce the next value on this stream.

Any successful values produced by this stream will not be passed to the closure, and will be passed through.

The returned value of the closure must implement the TryFuture trait and can represent some more work to be done before the composed stream is finished.

Note that this function consumes the receiving stream and returns a wrapped version of it.

fn inspect_ok<F>(self: Self, f: F) -> InspectOk<Self, F>
where
    F: FnMut(&<Self as >::Ok),
    Self: Sized

Do something with the success value of this stream, afterwards passing it on.

This is similar to the StreamExt::inspect method where it allows easily inspecting the success value as it passes through the stream, for example to debug what's going on.

fn inspect_err<F>(self: Self, f: F) -> InspectErr<Self, F>
where
    F: FnMut(&<Self as >::Error),
    Self: Sized

Do something with the error value of this stream, afterwards passing it on.

This is similar to the StreamExt::inspect method where it allows easily inspecting the error value as it passes through the stream, for example to debug what's going on.

fn into_stream(self: Self) -> IntoStream<Self>
where
    Self: Sized

Wraps a TryStream into a type that implements Stream

TryStreams currently do not implement the Stream trait because of limitations of the compiler.

Examples

use futures::stream::{Stream, TryStream, TryStreamExt};

# type T = i32;
# type E = ();
fn make_try_stream() -> impl TryStream<Ok = T, Error = E> { // ... }
# futures::stream::empty()
# }
fn take_stream(stream: impl Stream<Item = Result<T, E>>) { /* ... */ }

take_stream(make_try_stream().into_stream());
fn try_next(self: &mut Self) -> TryNext<'_, Self>
where
    Self: Unpin

Creates a future that attempts to resolve the next item in the stream. If an error is encountered before the next item, the error is returned instead.

This is similar to the Stream::next combinator, but returns a Result<Option<T>, E> rather than an Option<Result<T, E>>, making for easy use with the ? operator.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};

let mut stream = stream::iter(vec![Ok(()), Err(())]);

assert_eq!(stream.try_next().await, Ok(Some(())));
assert_eq!(stream.try_next().await, Err(()));
# })
fn try_for_each<Fut, F>(self: Self, f: F) -> TryForEach<Self, Fut, F>
where
    F: FnMut(<Self as >::Ok) -> Fut,
    Fut: TryFuture<Ok = (), Error = <Self as >::Error>,
    Self: Sized

Attempts to run this stream to completion, executing the provided asynchronous closure for each element on the stream.

The provided closure will be called for each item this stream produces, yielding a future. That future will then be executed to completion before moving on to the next item.

The returned value is a Future where the Output type is Result<(), Self::Error>. If any of the intermediate futures or the stream returns an error, this future will return immediately with an error.

Examples

# futures::executor::block_on(async {
use futures::future;
use futures::stream::{self, TryStreamExt};

let mut x = 0i32;

{
    let fut = stream::repeat(Ok(1)).try_for_each(|item| {
        x += item;
        future::ready(if x == 3 { Err(()) } else { Ok(()) })
    });
    assert_eq!(fut.await, Err(()));
}

assert_eq!(x, 3);
# })
fn try_skip_while<Fut, F>(self: Self, f: F) -> TrySkipWhile<Self, Fut, F>
where
    F: FnMut(&<Self as >::Ok) -> Fut,
    Fut: TryFuture<Ok = bool, Error = <Self as >::Error>,
    Self: Sized

Skip elements on this stream while the provided asynchronous predicate resolves to true.

This function is similar to StreamExt::skip_while but exits early if an error occurs.

Examples

# futures::executor::block_on(async {
use futures::future;
use futures::stream::{self, TryStreamExt};

let stream = stream::iter(vec![Ok::<i32, i32>(1), Ok(3), Ok(2)]);
let stream = stream.try_skip_while(|x| future::ready(Ok(*x < 3)));

let output: Result<Vec<i32>, i32> = stream.try_collect().await;
assert_eq!(output, Ok(vec![3, 2]));
# })
fn try_take_while<Fut, F>(self: Self, f: F) -> TryTakeWhile<Self, Fut, F>
where
    F: FnMut(&<Self as >::Ok) -> Fut,
    Fut: TryFuture<Ok = bool, Error = <Self as >::Error>,
    Self: Sized

Take elements on this stream while the provided asynchronous predicate resolves to true.

This function is similar to StreamExt::take_while but exits early if an error occurs.

Examples

# futures::executor::block_on(async {
use futures::future;
use futures::stream::{self, TryStreamExt};

let stream = stream::iter(vec![Ok::<i32, i32>(1), Ok(2), Ok(3), Ok(2)]);
let stream = stream.try_take_while(|x| future::ready(Ok(*x < 3)));

let output: Result<Vec<i32>, i32> = stream.try_collect().await;
assert_eq!(output, Ok(vec![1, 2]));
# })
fn try_for_each_concurrent<Fut, F, impl Into<Option<usize>>: Into<Option<usize>>>(self: Self, limit: impl Into<Option<usize>>, f: F) -> TryForEachConcurrent<Self, Fut, F>
where
    F: FnMut(<Self as >::Ok) -> Fut,
    Fut: Future<Output = Result<(), <Self as >::Error>>,
    Self: Sized

Attempts to run this stream to completion, executing the provided asynchronous closure for each element on the stream concurrently as elements become available, exiting as soon as an error occurs.

This is similar to StreamExt::for_each_concurrent, but will resolve to an error immediately if the underlying stream or the provided closure return an error.

This method is only available when the std or alloc feature of this library is activated, and it is activated by default.

Examples

# futures::executor::block_on(async {
use futures::channel::oneshot;
use futures::stream::{self, StreamExt, TryStreamExt};

let (tx1, rx1) = oneshot::channel();
let (tx2, rx2) = oneshot::channel();
let (_tx3, rx3) = oneshot::channel();

let stream = stream::iter(vec![rx1, rx2, rx3]);
let fut = stream.map(Ok).try_for_each_concurrent(
    /* limit */ 2,
    |rx| async move {
        let res: Result<(), oneshot::Canceled> = rx.await;
        res
    }
);

tx1.send(()).unwrap();
// Drop the second sender so that `rx2` resolves to `Canceled`.
drop(tx2);

// The final result is an error because the second future
// resulted in an error.
assert_eq!(Err(oneshot::Canceled), fut.await);
# })
fn try_collect<C: Default + Extend<<Self as >::Ok>>(self: Self) -> TryCollect<Self, C>
where
    Self: Sized

Attempt to transform a stream into a collection, returning a future representing the result of that computation.

This combinator will collect all successful results of this stream and collect them into the specified collection type. If an error happens then all collected elements will be dropped and the error will be returned.

The returned future will be resolved when the stream terminates.

Examples

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::TryStreamExt;
use std::thread;

let (tx, rx) = mpsc::unbounded();

thread::spawn(move || {
    for i in 1..=5 {
        tx.unbounded_send(Ok(i)).unwrap();
    }
    tx.unbounded_send(Err(6)).unwrap();
});

let output: Result<Vec<i32>, i32> = rx.try_collect().await;
assert_eq!(output, Err(6));
# })
fn try_chunks(self: Self, capacity: usize) -> TryChunks<Self>
where
    Self: Sized

An adaptor for chunking up successful items of the stream inside a vector.

This combinator will attempt to pull successful items from this stream and buffer them into a local vector. At most capacity items will get buffered before they're yielded from the returned stream.

Note that the vectors returned from this iterator may not always have capacity elements. If the underlying stream ended and only a partial vector was created, it'll be returned. Additionally if an error happens from the underlying stream then the currently buffered items will be yielded.

This method is only available when the std or alloc feature of this library is activated, and it is activated by default.

This function is similar to StreamExt::chunks but exits early if an error occurs.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryChunksError, TryStreamExt};

let stream = stream::iter(vec![Ok::<i32, i32>(1), Ok(2), Ok(3), Err(4), Ok(5), Ok(6)]);
let mut stream = stream.try_chunks(2);

assert_eq!(stream.try_next().await, Ok(Some(vec![1, 2])));
assert_eq!(stream.try_next().await, Err(TryChunksError(vec![3], 4)));
assert_eq!(stream.try_next().await, Ok(Some(vec![5, 6])));
# })

Panics

This method will panic if capacity is zero.

fn try_ready_chunks(self: Self, capacity: usize) -> TryReadyChunks<Self>
where
    Self: Sized

An adaptor for chunking up successful, ready items of the stream inside a vector.

This combinator will attempt to pull successful items from this stream and buffer them into a local vector. At most capacity items will get buffered before they're yielded from the returned stream. If the underlying stream returns Poll::Pending, and the collected chunk is not empty, it will be immediately returned.

Note that the vectors returned from this iterator may not always have capacity elements. If the underlying stream ended and only a partial vector was created, it'll be returned. Additionally if an error happens from the underlying stream then the currently buffered items will be yielded.

This method is only available when the std or alloc feature of this library is activated, and it is activated by default.

This function is similar to StreamExt::ready_chunks but exits early if an error occurs.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryReadyChunksError, TryStreamExt};

let stream = stream::iter(vec![Ok::<i32, i32>(1), Ok(2), Ok(3), Err(4), Ok(5), Ok(6)]);
let mut stream = stream.try_ready_chunks(2);

assert_eq!(stream.try_next().await, Ok(Some(vec![1, 2])));
assert_eq!(stream.try_next().await, Err(TryReadyChunksError(vec![3], 4)));
assert_eq!(stream.try_next().await, Ok(Some(vec![5, 6])));
# })

Panics

This method will panic if capacity is zero.

fn try_filter<Fut, F>(self: Self, f: F) -> TryFilter<Self, Fut, F>
where
    Fut: Future<Output = bool>,
    F: FnMut(&<Self as >::Ok) -> Fut,
    Self: Sized

Attempt to filter the values produced by this stream according to the provided asynchronous closure.

As values of this stream are made available, the provided predicate f will be run on them. If the predicate returns a Future which resolves to true, then the stream will yield the value, but if the predicate return a Future which resolves to false, then the value will be discarded and the next value will be produced.

All errors are passed through without filtering in this combinator.

Note that this function consumes the stream passed into it and returns a wrapped version of it, similar to the existing filter methods in the standard library.

Examples

# futures::executor::block_on(async {
use futures::future;
use futures::stream::{self, StreamExt, TryStreamExt};

let stream = stream::iter(vec![Ok(1i32), Ok(2i32), Ok(3i32), Err("error")]);
let mut evens = stream.try_filter(|x| {
    future::ready(x % 2 == 0)
});

assert_eq!(evens.next().await, Some(Ok(2)));
assert_eq!(evens.next().await, Some(Err("error")));
# })
fn try_filter_map<Fut, F, T>(self: Self, f: F) -> TryFilterMap<Self, Fut, F>
where
    Fut: TryFuture<Ok = Option<T>, Error = <Self as >::Error>,
    F: FnMut(<Self as >::Ok) -> Fut,
    Self: Sized

Attempt to filter the values produced by this stream while simultaneously mapping them to a different type according to the provided asynchronous closure.

As values of this stream are made available, the provided function will be run on them. If the future returned by the predicate f resolves to Some(item) then the stream will yield the value item, but if it resolves to None then the next value will be produced.

All errors are passed through without filtering in this combinator.

Note that this function consumes the stream passed into it and returns a wrapped version of it, similar to the existing filter_map methods in the standard library.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, StreamExt, TryStreamExt};
use futures::pin_mut;

let stream = stream::iter(vec![Ok(1i32), Ok(6i32), Err("error")]);
let halves = stream.try_filter_map(|x| async move {
    let ret = if x % 2 == 0 { Some(x / 2) } else { None };
    Ok(ret)
});

pin_mut!(halves);
assert_eq!(halves.next().await, Some(Ok(3)));
assert_eq!(halves.next().await, Some(Err("error")));
# })
fn try_flatten_unordered<impl Into<Option<usize>>: Into<Option<usize>>>(self: Self, limit: impl Into<Option<usize>>) -> TryFlattenUnordered<Self>
where
    <Self as >::Ok: TryStream + Unpin,
    <<Self as >::Ok as TryStream>::Error: From<<Self as >::Error>,
    Self: Sized

Flattens a stream of streams into just one continuous stream. Produced streams will be polled concurrently and any errors will be passed through without looking at them. If the underlying base stream returns an error, it will be immediately propagated.

The only argument is an optional limit on the number of concurrently polled streams. If this limit is not None, no more than limit streams will be polled at the same time. The limit argument is of type Into<Option<usize>>, and so can be provided as either None, Some(10), or just 10. Note: a limit of zero is interpreted as no limit at all, and will have the same result as passing in None.

Examples

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::{StreamExt, TryStreamExt};
use std::thread;

let (tx1, rx1) = mpsc::unbounded();
let (tx2, rx2) = mpsc::unbounded();
let (tx3, rx3) = mpsc::unbounded();

thread::spawn(move || {
    tx1.unbounded_send(Ok(1)).unwrap();
});
thread::spawn(move || {
    tx2.unbounded_send(Ok(2)).unwrap();
    tx2.unbounded_send(Err(3)).unwrap();
    tx2.unbounded_send(Ok(4)).unwrap();
});
thread::spawn(move || {
    tx3.unbounded_send(Ok(rx1)).unwrap();
    tx3.unbounded_send(Ok(rx2)).unwrap();
    tx3.unbounded_send(Err(5)).unwrap();
});

let stream = rx3.try_flatten_unordered(None);
let mut values: Vec<_> = stream.collect().await;
values.sort();

assert_eq!(values, vec![Ok(1), Ok(2), Ok(4), Err(3), Err(5)]);
# });
fn try_flatten(self: Self) -> TryFlatten<Self>
where
    <Self as >::Ok: TryStream,
    <<Self as >::Ok as TryStream>::Error: From<<Self as >::Error>,
    Self: Sized

Flattens a stream of streams into just one continuous stream.

If this stream's elements are themselves streams then this combinator will flatten out the entire stream to one long chain of elements. Any errors are passed through without looking at them, but otherwise each individual stream will get exhausted before moving on to the next.

Examples

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::{StreamExt, TryStreamExt};
use std::thread;

let (tx1, rx1) = mpsc::unbounded();
let (tx2, rx2) = mpsc::unbounded();
let (tx3, rx3) = mpsc::unbounded();

thread::spawn(move || {
    tx1.unbounded_send(Ok(1)).unwrap();
});
thread::spawn(move || {
    tx2.unbounded_send(Ok(2)).unwrap();
    tx2.unbounded_send(Err(3)).unwrap();
    tx2.unbounded_send(Ok(4)).unwrap();
});
thread::spawn(move || {
    tx3.unbounded_send(Ok(rx1)).unwrap();
    tx3.unbounded_send(Ok(rx2)).unwrap();
    tx3.unbounded_send(Err(5)).unwrap();
});

let mut stream = rx3.try_flatten();
assert_eq!(stream.next().await, Some(Ok(1)));
assert_eq!(stream.next().await, Some(Ok(2)));
assert_eq!(stream.next().await, Some(Err(3)));
assert_eq!(stream.next().await, Some(Ok(4)));
assert_eq!(stream.next().await, Some(Err(5)));
assert_eq!(stream.next().await, None);
# });
fn try_fold<T, Fut, F>(self: Self, init: T, f: F) -> TryFold<Self, Fut, T, F>
where
    F: FnMut(T, <Self as >::Ok) -> Fut,
    Fut: TryFuture<Ok = T, Error = <Self as >::Error>,
    Self: Sized

Attempt to execute an accumulating asynchronous computation over a stream, collecting all the values into one final result.

This combinator will accumulate all values returned by this stream according to the closure provided. The initial state is also provided to this method and then is returned again by each execution of the closure. Once the entire stream has been exhausted the returned future will resolve to this value.

This method is similar to fold, but will exit early if an error is encountered in either the stream or the provided closure.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};

let number_stream = stream::iter(vec![Ok::<i32, i32>(1), Ok(2)]);
let sum = number_stream.try_fold(0, |acc, x| async move { Ok(acc + x) });
assert_eq!(sum.await, Ok(3));

let number_stream_with_err = stream::iter(vec![Ok::<i32, i32>(1), Err(2), Ok(1)]);
let sum = number_stream_with_err.try_fold(0, |acc, x| async move { Ok(acc + x) });
assert_eq!(sum.await, Err(2));
# })
fn try_concat(self: Self) -> TryConcat<Self>
where
    Self: Sized,
    <Self as >::Ok: Extend<<<Self as TryStream>::Ok as IntoIterator>::Item> + IntoIterator + Default

Attempt to concatenate all items of a stream into a single extendable destination, returning a future representing the end result.

This combinator will extend the first item with the contents of all the subsequent successful results of the stream. If the stream is empty, the default value will be returned.

Works with all collections that implement the Extend trait.

This method is similar to concat, but will exit early if an error is encountered in the stream.

Examples

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::TryStreamExt;
use std::thread;

let (tx, rx) = mpsc::unbounded::<Result<Vec<i32>, ()>>();

thread::spawn(move || {
    for i in (0..3).rev() {
        let n = i * 3;
        tx.unbounded_send(Ok(vec![n + 1, n + 2, n + 3])).unwrap();
    }
});

let result = rx.try_concat().await;

assert_eq!(result, Ok(vec![7, 8, 9, 4, 5, 6, 1, 2, 3]));
# });
fn try_buffer_unordered(self: Self, n: usize) -> TryBufferUnordered<Self>
where
    <Self as >::Ok: TryFuture<Error = <Self as >::Error>,
    Self: Sized

Attempt to execute several futures from a stream concurrently (unordered).

This stream's Ok type must be a TryFuture with an Error type that matches the stream's Error type.

This adaptor will buffer up to n futures and then return their outputs in the order in which they complete. If the underlying stream returns an error, it will be immediately propagated.

The returned stream will be a stream of results, each containing either an error or a future's output. An error can be produced either by the underlying stream itself or by one of the futures it yielded.

This method is only available when the std or alloc feature of this library is activated, and it is activated by default.

Examples

Results are returned in the order of completion:

# futures::executor::block_on(async {
use futures::channel::oneshot;
use futures::stream::{self, StreamExt, TryStreamExt};

let (send_one, recv_one) = oneshot::channel();
let (send_two, recv_two) = oneshot::channel();

let stream_of_futures = stream::iter(vec![Ok(recv_one), Ok(recv_two)]);

let mut buffered = stream_of_futures.try_buffer_unordered(10);

send_two.send(2i32)?;
assert_eq!(buffered.next().await, Some(Ok(2i32)));

send_one.send(1i32)?;
assert_eq!(buffered.next().await, Some(Ok(1i32)));

assert_eq!(buffered.next().await, None);
# Ok::<(), i32>(()) }).unwrap();

Errors from the underlying stream itself are propagated:

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::{StreamExt, TryStreamExt};

let (sink, stream_of_futures) = mpsc::unbounded();
let mut buffered = stream_of_futures.try_buffer_unordered(10);

sink.unbounded_send(Ok(async { Ok(7i32) }))?;
assert_eq!(buffered.next().await, Some(Ok(7i32)));

sink.unbounded_send(Err("error in the stream"))?;
assert_eq!(buffered.next().await, Some(Err("error in the stream")));
# Ok::<(), Box<dyn std::error::Error>>(()) }).unwrap();
fn try_buffered(self: Self, n: usize) -> TryBuffered<Self>
where
    <Self as >::Ok: TryFuture<Error = <Self as >::Error>,
    Self: Sized

Attempt to execute several futures from a stream concurrently.

This stream's Ok type must be a TryFuture with an Error type that matches the stream's Error type.

This adaptor will buffer up to n futures and then return their outputs in the same order as the underlying stream. If the underlying stream returns an error, it will be immediately propagated.

The returned stream will be a stream of results, each containing either an error or a future's output. An error can be produced either by the underlying stream itself or by one of the futures it yielded.

This method is only available when the std or alloc feature of this library is activated, and it is activated by default.

Examples

Results are returned in the order of addition:

# futures::executor::block_on(async {
use futures::channel::oneshot;
use futures::future::lazy;
use futures::stream::{self, StreamExt, TryStreamExt};

let (send_one, recv_one) = oneshot::channel();
let (send_two, recv_two) = oneshot::channel();

let mut buffered = lazy(move |cx| {
    let stream_of_futures = stream::iter(vec![Ok(recv_one), Ok(recv_two)]);

    let mut buffered = stream_of_futures.try_buffered(10);

    assert!(buffered.try_poll_next_unpin(cx).is_pending());

    send_two.send(2i32)?;
    assert!(buffered.try_poll_next_unpin(cx).is_pending());
    Ok::<_, i32>(buffered)
}).await?;

send_one.send(1i32)?;
assert_eq!(buffered.next().await, Some(Ok(1i32)));
assert_eq!(buffered.next().await, Some(Ok(2i32)));

assert_eq!(buffered.next().await, None);
# Ok::<(), i32>(()) }).unwrap();

Errors from the underlying stream itself are propagated:

# futures::executor::block_on(async {
use futures::channel::mpsc;
use futures::stream::{StreamExt, TryStreamExt};

let (sink, stream_of_futures) = mpsc::unbounded();
let mut buffered = stream_of_futures.try_buffered(10);

sink.unbounded_send(Ok(async { Ok(7i32) }))?;
assert_eq!(buffered.next().await, Some(Ok(7i32)));

sink.unbounded_send(Err("error in the stream"))?;
assert_eq!(buffered.next().await, Some(Err("error in the stream")));
# Ok::<(), Box<dyn std::error::Error>>(()) }).unwrap();
fn try_poll_next_unpin(self: &mut Self, cx: &mut Context<'_>) -> Poll<Option<Result<<Self as >::Ok, <Self as >::Error>>>
where
    Self: Unpin

A convenience method for calling TryStream::try_poll_next on Unpin stream types.

fn into_async_read(self: Self) -> IntoAsyncRead<Self>
where
    Self: Sized + TryStreamExt<Error = Error>,
    <Self as >::Ok: AsRef<[u8]>

Adapter that converts this stream into an AsyncBufRead.

This method is only available when the std feature of this library is activated, and it is activated by default.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, TryStreamExt};
use futures::io::AsyncReadExt;

let stream = stream::iter([Ok(vec![1, 2, 3]), Ok(vec![4, 5])]);
let mut reader = stream.into_async_read();

let mut buf = Vec::new();
reader.read_to_end(&mut buf).await.unwrap();
assert_eq!(buf, [1, 2, 3, 4, 5]);
# })
fn try_all<Fut, F>(self: Self, f: F) -> TryAll<Self, Fut, F>
where
    Self: Sized,
    F: FnMut(<Self as >::Ok) -> Fut,
    Fut: Future<Output = bool>

Attempt to execute a predicate over an asynchronous stream and evaluate if all items satisfy the predicate. Exits early if an Err is encountered or if an Ok item is found that does not satisfy the predicate.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, StreamExt, TryStreamExt};
use std::convert::Infallible;

let number_stream = stream::iter(1..10).map(Ok::<_, Infallible>);
let positive = number_stream.try_all(|i| async move { i > 0 });
assert_eq!(positive.await, Ok(true));

let stream_with_errors = stream::iter([Ok(1), Err("err"), Ok(3)]);
let positive = stream_with_errors.try_all(|i| async move { i > 0 });
assert_eq!(positive.await, Err("err"));
# });
fn try_any<Fut, F>(self: Self, f: F) -> TryAny<Self, Fut, F>
where
    Self: Sized,
    F: FnMut(<Self as >::Ok) -> Fut,
    Fut: Future<Output = bool>

Attempt to execute a predicate over an asynchronous stream and evaluate if any items satisfy the predicate. Exits early if an Err is encountered or if an Ok item is found that satisfies the predicate.

Examples

# futures::executor::block_on(async {
use futures::stream::{self, StreamExt, TryStreamExt};
use std::convert::Infallible;

let number_stream = stream::iter(0..10).map(Ok::<_, Infallible>);
let contain_three = number_stream.try_any(|i| async move { i == 3 });
assert_eq!(contain_three.await, Ok(true));

let stream_with_errors = stream::iter([Ok(1), Err("err"), Ok(3)]);
let contain_three = stream_with_errors.try_any(|i| async move { i == 3 });
assert_eq!(contain_three.await, Err("err"));
# });

Implementors