Function join
fn join<Fut1, Fut2>(future1: Fut1, future2: Fut2) -> Join<Fut1, Fut2>
where
Fut1: Future,
Fut2: Future
Joins the result of two futures, waiting for them both to complete.
This function will return a new future which awaits both futures to complete. The returned future will finish with a tuple of both results.
Note that this function consumes the passed futures and returns a wrapped version of it.
Examples
# block_on;