Function lazy
fn lazy<F, R>(f: F) -> Lazy<F>
where
F: FnOnce(&mut Context<'_>) -> R
Creates a new future that allows delayed execution of a closure.
The provided closure is only run once the future is polled.
Examples
# block_on;