Function empty
fn empty() -> Empty
Constructs a new handle to an empty reader.
All reads from the returned reader will return Poll::Ready(Ok(0)).
Examples
A slightly sad example of not reading anything into a buffer:
# block_on.unwrap;