Struct Chain
struct Chain<T, U> { ... }
Reader for the chain method.
Implementations
impl<T, U> Chain<T, U>
fn get_ref(self: &Self) -> (&T, &U)Gets references to the underlying readers in this
Chain.fn get_mut(self: &mut Self) -> (&mut T, &mut U)Gets mutable references to the underlying readers in this
Chain.Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this
Chain.fn get_pin_mut(self: Pin<&mut Self>) -> (Pin<&mut T>, Pin<&mut U>)Gets pinned mutable references to the underlying readers in this
Chain.Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this
Chain.fn into_inner(self: Self) -> (T, U)Consumes the
Chain, returning the wrapped readers.
impl<'__pin, T, U> Unpin for Chain<T, U>
impl<R> AsyncBufReadExt for Chain<T, U>
impl<R> AsyncReadExt for Chain<T, U>
impl<T> Any for Chain<T, U>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Chain<T, U>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Chain<T, U>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Chain<T, U>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> AsyncBufRead for Chain<T, U>
fn poll_fill_buf(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<&[u8]>>fn consume(self: Pin<&mut Self>, amt: usize)
impl<T, U> AsyncRead for Chain<T, U>
fn poll_read(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &mut [u8]) -> Poll<Result<usize>>fn poll_read_vectored(self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &mut [IoSliceMut<'_>]) -> Poll<Result<usize>>
impl<T, U> Debug for Chain<T, U>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, U> Freeze for Chain<T, U>
impl<T, U> Into for Chain<T, U>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> RefUnwindSafe for Chain<T, U>
impl<T, U> Send for Chain<T, U>
impl<T, U> Sync for Chain<T, U>
impl<T, U> TryFrom for Chain<T, U>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Chain<T, U>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>