Struct WriteHalf

struct WriteHalf<T> { ... }

The writable half of an object returned from AsyncRead::split.

Implementations

impl<T> WriteHalf<T>

fn is_pair_of(self: &Self, other: &ReadHalf<T>) -> bool

Checks if this WriteHalf and some ReadHalf were split from the same stream.

impl<T: Unpin> WriteHalf<T>

fn reunite(self: Self, other: ReadHalf<T>) -> Result<T, ReuniteError<T>>

Attempts to put the two "halves" of a split AsyncRead + AsyncWrite back together. Succeeds only if the ReadHalf<T> and WriteHalf<T> are a matching pair originating from the same call to AsyncReadExt::split.

impl<T> Any for WriteHalf<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for WriteHalf<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for WriteHalf<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Freeze for WriteHalf<T>

impl<T> From for WriteHalf<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for WriteHalf<T>

impl<T> Send for WriteHalf<T>

impl<T> Sync for WriteHalf<T>

impl<T> Unpin for WriteHalf<T>

impl<T> UnsafeUnpin for WriteHalf<T>

impl<T> UnwindSafe for WriteHalf<T>

impl<T, U> Into for WriteHalf<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for WriteHalf<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for WriteHalf<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::fmt::Debug> Debug for WriteHalf<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<W> AsyncWriteExt for WriteHalf<T>

impl<W: AsyncWrite> AsyncWrite for WriteHalf<W>

fn poll_write(self: Pin<&mut Self>, cx: &mut Context<'_>, buf: &[u8]) -> Poll<Result<usize>>
fn poll_write_vectored(self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &[IoSlice<'_>]) -> Poll<Result<usize>>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<()>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<()>>