Macro stream_select
macro_rules! stream_select {
($($tokens:tt)*) => { ... };
}
Combines several streams, all producing the same Item type, into one stream.
This is similar to select_all but does not require the streams to all be the same type.
It also keeps the streams inline, and does not require Box<dyn Stream>s to be allocated.
Streams passed to this macro must be Unpin.
If multiple streams are ready, one will be pseudo randomly selected at runtime.
Examples
# block_on;