Macro try_join
macro_rules! try_join {
($($tokens:tt)*) => { ... };
}
Polls multiple futures simultaneously, resolving to a Result containing
either a tuple of the successful outputs or an error.
try_join! is similar to [join!], but completes immediately if any of
the futures return an error.
This macro is only usable inside of async functions, closures, and blocks.
It is also gated behind the async-await feature of this library, which is
activated by default.
Examples
When used on multiple futures that return Ok, try_join! will return
Ok of a tuple of the values:
# block_on;
If one of the futures resolves to an error, try_join! will return
that error:
# block_on;