Struct SinkMapErr

struct SinkMapErr<Si, F> { ... }

Sink for the sink_map_err method.

Implementations

impl<Si, F> SinkMapErr<Si, F>

fn get_ref(self: &Self) -> &Si

Acquires a reference to the underlying sink or stream that this combinator is pulling from.

fn get_mut(self: &mut Self) -> &mut Si

Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Si>

Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.

Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.

fn into_inner(self: Self) -> Si

Consumes this combinator, returning the underlying sink or stream.

Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.

impl<'__pin, Si, F> Unpin for SinkMapErr<Si, F>

impl<S> TryStreamExt for SinkMapErr<Si, F>

impl<S, T, E> TryStream for SinkMapErr<Si, F>

fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>

impl<S: FusedStream, F> FusedStream for SinkMapErr<S, F>

fn is_terminated(self: &Self) -> bool

impl<S: Stream, F> Stream for SinkMapErr<S, F>

fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<Si, F> Freeze for SinkMapErr<Si, F>

impl<Si, F> RefUnwindSafe for SinkMapErr<Si, F>

impl<Si, F> Send for SinkMapErr<Si, F>

impl<Si, F> Sync for SinkMapErr<Si, F>

impl<Si, F> UnsafeUnpin for SinkMapErr<Si, F>

impl<Si, F> UnwindSafe for SinkMapErr<Si, F>

impl<Si, F, E, Item> Sink for SinkMapErr<Si, F>

fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>
fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>

impl<Si: $crate::clone::Clone, F: $crate::clone::Clone> Clone for SinkMapErr<Si, F>

fn clone(self: &Self) -> SinkMapErr<Si, F>

impl<Si: $crate::fmt::Debug, F: $crate::fmt::Debug> Debug for SinkMapErr<Si, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for SinkMapErr<Si, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SinkMapErr<Si, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SinkMapErr<Si, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SinkMapErr<Si, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SinkMapErr<Si, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> StreamExt for SinkMapErr<Si, F>

impl<T> ToOwned for SinkMapErr<Si, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, Item> SinkExt for SinkMapErr<Si, F>

impl<T, U> Into for SinkMapErr<Si, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SinkMapErr<Si, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SinkMapErr<Si, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>