Struct WithFlatMap
struct WithFlatMap<Si, Item, U, St, F> { ... }
Sink for the with_flat_map method.
Implementations
impl<Si, Item, U, St, F> WithFlatMap<Si, Item, U, St, F>
fn get_ref(self: &Self) -> &SiAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut SiAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Si>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> SiConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, Si, Item, U, St, F> Unpin for WithFlatMap<Si, Item, U, St, F>
impl<S> TryStreamExt for WithFlatMap<Si, Item, U, St, F>
impl<S, Item, U, St, F> FusedStream for WithFlatMap<S, Item, U, St, F>
fn is_terminated(self: &Self) -> bool
impl<S, Item, U, St, F> Stream for WithFlatMap<S, Item, U, St, F>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<S, T, E> TryStream for WithFlatMap<Si, Item, U, St, F>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<Si, Item, U, St, F> Debug for WithFlatMap<Si, Item, U, St, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<Si, Item, U, St, F> Freeze for WithFlatMap<Si, Item, U, St, F>
impl<Si, Item, U, St, F> RefUnwindSafe for WithFlatMap<Si, Item, U, St, F>
impl<Si, Item, U, St, F> Send for WithFlatMap<Si, Item, U, St, F>
impl<Si, Item, U, St, F> Sink for WithFlatMap<Si, Item, U, St, F>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: U) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
impl<Si, Item, U, St, F> Sync for WithFlatMap<Si, Item, U, St, F>
impl<Si, Item, U, St, F> UnsafeUnpin for WithFlatMap<Si, Item, U, St, F>
impl<Si, Item, U, St, F> UnwindSafe for WithFlatMap<Si, Item, U, St, F>
impl<T> Any for WithFlatMap<Si, Item, U, St, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for WithFlatMap<Si, Item, U, St, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for WithFlatMap<Si, Item, U, St, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for WithFlatMap<Si, Item, U, St, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for WithFlatMap<Si, Item, U, St, F>
impl<T, Item> SinkExt for WithFlatMap<Si, Item, U, St, F>
impl<T, U> Into for WithFlatMap<Si, Item, U, St, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for WithFlatMap<Si, Item, U, St, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for WithFlatMap<Si, Item, U, St, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>