Struct ErrInto
struct ErrInto<St, E> { ... }
Stream for the err_into method.
Implementations
impl<St, E> ErrInto<St, E>
fn get_ref(self: &Self) -> &StAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut StAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> StConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St, E> Unpin for ErrInto<St, E>
impl<S> TryStreamExt for ErrInto<St, E>
impl<S, T, E> TryStream for ErrInto<St, E>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<St, E> Debug for ErrInto<St, E>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St, E> Freeze for ErrInto<St, E>
impl<St, E> FusedStream for ErrInto<St, E>
fn is_terminated(self: &Self) -> bool
impl<St, E> RefUnwindSafe for ErrInto<St, E>
impl<St, E> Send for ErrInto<St, E>
impl<St, E> Stream for ErrInto<St, E>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<St, E> Sync for ErrInto<St, E>
impl<St, E> UnsafeUnpin for ErrInto<St, E>
impl<St, E> UnwindSafe for ErrInto<St, E>
impl<T> Any for ErrInto<St, E>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ErrInto<St, E>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ErrInto<St, E>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ErrInto<St, E>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for ErrInto<St, E>
impl<T, Item> SinkExt for ErrInto<St, E>
impl<T, U> Into for ErrInto<St, E>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ErrInto<St, E>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ErrInto<St, E>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<_Item, St, E> Sink for ErrInto<St, E>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: _Item) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>