Struct TryChunksError
struct TryChunksError<T, E>(4141, 4142)
Error indicating, that while chunk was collected inner stream produced an error.
Contains all items that were collected before an error occurred, and the stream error itself.
Implementations
impl<T> Any for TryChunksError<T, E>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TryChunksError<T, E>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TryChunksError<T, E>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for TryChunksError<T, E>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for TryChunksError<T, E>
fn to_string(self: &Self) -> String
impl<T, E> Freeze for TryChunksError<T, E>
impl<T, E> RefUnwindSafe for TryChunksError<T, E>
impl<T, E> Send for TryChunksError<T, E>
impl<T, E> StructuralPartialEq for TryChunksError<T, E>
impl<T, E> Sync for TryChunksError<T, E>
impl<T, E> Unpin for TryChunksError<T, E>
impl<T, E> UnsafeUnpin for TryChunksError<T, E>
impl<T, E> UnwindSafe for TryChunksError<T, E>
impl<T, E: fmt::Debug + fmt::Display> Error for TryChunksError<T, E>
impl<T, E: fmt::Debug> Debug for TryChunksError<T, E>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, E: fmt::Display> Display for TryChunksError<T, E>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, U> Into for TryChunksError<T, E>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TryChunksError<T, E>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TryChunksError<T, E>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::cmp::Eq, E: $crate::cmp::Eq> Eq for TryChunksError<T, E>
impl<T: $crate::cmp::PartialEq, E: $crate::cmp::PartialEq> PartialEq for TryChunksError<T, E>
fn eq(self: &Self, other: &TryChunksError<T, E>) -> bool