Struct TryReadyChunks
struct TryReadyChunks<St: TryStream> { ... }
Stream for the try_ready_chunks method.
Implementations
impl<St: TryStream> TryReadyChunks<St>
fn get_ref(self: &Self) -> &StAcquires a reference to the underlying sink or stream that this combinator is pulling from.
fn get_mut(self: &mut Self) -> &mut StAcquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut St>Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
fn into_inner(self: Self) -> StConsumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
impl<'__pin, St: TryStream> Unpin for TryReadyChunks<St>
impl<S> TryStreamExt for TryReadyChunks<St>
impl<S, Item> Sink for TryReadyChunks<S>
fn poll_ready(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn start_send(self: Pin<&mut Self>, item: Item) -> Result<(), <Self as >::Error>fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn poll_close(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
impl<S, T, E> TryStream for TryReadyChunks<St>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<St> Freeze for TryReadyChunks<St>
impl<St> RefUnwindSafe for TryReadyChunks<St>
impl<St> Send for TryReadyChunks<St>
impl<St> Sync for TryReadyChunks<St>
impl<St> UnsafeUnpin for TryReadyChunks<St>
impl<St> UnwindSafe for TryReadyChunks<St>
impl<St: $crate::fmt::Debug + TryStream> Debug for TryReadyChunks<St>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<St: TryStream + FusedStream> FusedStream for TryReadyChunks<St>
fn is_terminated(self: &Self) -> bool
impl<St: TryStream> Stream for TryReadyChunks<St>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<T> Any for TryReadyChunks<St>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TryReadyChunks<St>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TryReadyChunks<St>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for TryReadyChunks<St>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> StreamExt for TryReadyChunks<St>
impl<T, Item> SinkExt for TryReadyChunks<St>
impl<T, U> Into for TryReadyChunks<St>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TryReadyChunks<St>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TryReadyChunks<St>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>