Trait LocalSpawnExt
trait LocalSpawnExt: LocalSpawn
Extension trait for LocalSpawn.
Provided Methods
fn spawn_local<Fut>(self: &Self, future: Fut) -> Result<(), SpawnError> where Fut: Future<Output = ()> + 'staticSpawns a task that polls the given future with output
()to completion.This method returns a
Resultthat contains aSpawnErrorif spawning fails.You can use
spawn_with_handleif you want to spawn a future with output other than()or if you want to be able to await its completion.Note this method will eventually be replaced with the upcoming
Spawn::spawnmethod which will take adyn Futureas input. Technical limitations preventSpawn::spawnfrom being implemented today. Feel free to use this method in the meantime.use LocalPool; use LocalSpawnExt; let executor = new; let spawner = executor.spawner; let future = async ; spawner.spawn_local.unwrap;fn spawn_local_with_handle<Fut>(self: &Self, future: Fut) -> Result<RemoteHandle<<Fut as >::Output>, SpawnError> where Fut: Future + 'staticSpawns a task that polls the given future to completion and returns a future that resolves to the spawned future's output.
This method returns a
Resultthat contains aRemoteHandle, or, if spawning fails, aSpawnError.RemoteHandleis a future that resolves to the output of the spawned future.use LocalPool; use LocalSpawnExt; let mut executor = new; let spawner = executor.spawner; let future = async ; let join_handle_fut = spawner.spawn_local_with_handle.unwrap; assert_eq!;
Implementors
impl<Sp> LocalSpawnExt for FuturesUnordered<Fut>impl<Sp> LocalSpawnExt for Sp